'''
Manage web apps.
'''
from .. pyaz_utils import _call_az
from . import auth, config, connection, cors, deleted, hybrid_connection, identity, log, traffic_routing, vnet_integration


def create(name, plan, resource_group, assign_identity=None, deployment_container_image_name=None, deployment_local_git=None, deployment_source_branch=None, deployment_source_url=None, docker_registry_server_password=None, docker_registry_server_user=None, multicontainer_config_file=None, multicontainer_config_type=None, role=None, runtime=None, scope=None, startup_file=None, subnet=None, tags=None, vnet=None):
    '''
    Create a web app.

    Required Parameters:
    - name -- name of the new web app
    - plan -- name or resource id of the app service plan. Use 'appservice plan create' to get one
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - assign_identity -- accept system or user assigned identities separated by spaces. Use '[system]' to refer system assigned identity, or a resource id to refer user assigned identity. Check out help for more examples
    - deployment_container_image_name -- Container image name from Docker Hub, e.g. publisher/image-name:tag
    - deployment_local_git -- enable local git
    - deployment_source_branch -- the branch to deploy
    - deployment_source_url -- Git repository URL to link with manual integration
    - docker_registry_server_password -- The container registry server password. Required for private registries.
    - docker_registry_server_user -- the container registry server username
    - multicontainer_config_file -- Linux only. Config file for multicontainer apps. (local or remote)
    - multicontainer_config_type -- Linux only.
    - role -- Role name or id the system assigned identity will have
    - runtime -- canonicalized web runtime in the format of Framework|Version, e.g. "PHP|7.2". Allowed delimiters: "|" or ":". Use `az webapp list-runtimes` for available list
    - scope -- Scope that the system assigned identity can access
    - startup_file -- Linux only. The web's startup file
    - subnet -- Name or resource ID of the pre-existing subnet to have the webapp join. The --vnet is argument also needed if specifying subnet by name.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet -- Name or resource ID of the regional virtual network. If there are multiple vnets of the same name across different resource groups, use vnet resource id to specify which vnet to use. If vnet name is used, by default, the vnet in the same resource group as the webapp will be used. Must be used with --subnet argument.
    '''
    return _call_az("az webapp create", locals())


def up(app_service_environment=None, dryrun=None, html=None, launch_browser=None, location=None, logs=None, name=None, os_type=None, plan=None, resource_group=None, runtime=None, sku=None):
    '''
    Create a webapp and deploy code from a local workspace to the app. The command is required to run from the folder where the code is present. Current support includes Node, Python, .NET Core and ASP.NET. Node, Python apps are created as Linux apps. .Net Core, ASP.NET, and static HTML apps are created as Windows apps. Append the html flag to deploy as a static HTML app.


    Optional Parameters:
    - app_service_environment -- name of the (pre-existing) App Service Environment to deploy to. Requires an Isolated V2 sku [I1v2, I2v2, I3v2]
    - dryrun -- show summary of the create and deploy operation instead of executing it
    - html -- Ignore app detection and deploy as an html app
    - launch_browser -- Launch the created app using the default browser
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - logs -- Configure default logging required to enable viewing log stream immediately after launching the webapp
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - os_type -- Set the OS type for the app to be created.
    - plan -- name of the appserviceplan associated with the webapp
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - runtime -- canonicalized web runtime in the format of Framework|Version, e.g. "PHP|7.2". Allowed delimiters: "|" or ":". Use `az webapp list-runtimes` for available list.
    - sku -- The pricing tiers, e.g., F1(Free), D1(Shared), B1(Basic Small), B2(Basic Medium), B3(Basic Large), S1(Standard Small), P1V2(Premium V2 Small), P1V3(Premium V3 Small), P2V3(Premium V3 Medium), P3V3(Premium V3 Large), PC2 (Premium Container Small), PC3 (Premium Container Medium), PC4 (Premium Container Large), I1 (Isolated Small), I2 (Isolated Medium), I3 (Isolated Large), I1v2 (Isolated V2 Small), I2v2 (Isolated V2 Medium), I3v2 (Isolated V2 Large)
    '''
    return _call_az("az webapp up", locals())


def ssh(name, resource_group, instance=None, port=None, slot=None, timeout=None):
    '''
    SSH command establishes a ssh session to the web container and developer would get a shell terminal remotely.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance -- Webapp instance to connect to. Defaults to none.
    - port -- Port for the remote connection. Default: Random available port
    - slot -- the name of the slot. Default to the productions slot if not specified
    - timeout -- timeout in seconds. Defaults to none
    '''
    return _call_az("az webapp ssh", locals())


def list(resource_group=None):
    '''
    List web apps.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az webapp list", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp show", locals())


def delete(name, resource_group, keep_dns_registration=None, keep_empty_plan=None, keep_metrics=None, slot=None):
    '''
    Delete a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - keep_dns_registration -- keep DNS registration
    - keep_empty_plan -- keep empty app service plan
    - keep_metrics -- keep app metrics
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp delete", locals())


def stop(name, resource_group, slot=None):
    '''
    Stop a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp stop", locals())


def start(name, resource_group, slot=None):
    '''
    Start a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp start", locals())


def restart(name, resource_group, slot=None):
    '''
    Restart a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp restart", locals())


def browse(name, resource_group, logs=None, slot=None):
    '''
    Open a web app in a browser.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - logs -- Enable viewing the log stream immediately after launching the web app
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp browse", locals())


def list_instances(name, resource_group, slot=None):
    '''
    List all scaled out instances of a web app or web app slot.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- Name of the web app slot. Default to the productions slot if not specified.
    '''
    return _call_az("az webapp list-instances", locals())


def list_runtimes(linux=None):
    '''
    List available built-in stacks which can be used for web apps.

    Optional Parameters:
    - linux -- list runtime stacks for linux based web apps
    '''
    return _call_az("az webapp list-runtimes", locals())


def create_remote_connection(name, resource_group, instance=None, port=None, slot=None, timeout=None):
    '''
    Creates a remote connection using a tcp tunnel to your web app

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance -- Webapp instance to connect to. Defaults to none.
    - port -- Port for the remote connection. Default: Random available port
    - slot -- the name of the slot. Default to the productions slot if not specified
    - timeout -- timeout in seconds. Defaults to none
    '''
    return _call_az("az webapp create-remote-connection", locals())


def deploy(name, resource_group, async_=None, clean=None, ignore_stack=None, restart=None, slot=None, src_path=None, src_url=None, target_path=None, timeout=None, type=None):
    '''
    Deploys a provided artifact to Azure Web Apps.

    Required Parameters:
    - name -- Name of the webapp to deploy to.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - async_ -- If true, the artifact is deployed asynchronously. (The command will exit once the artifact is pushed to the web app.)
    - clean -- If true, cleans the target directory prior to deploying the file(s). Default value is determined based on artifact type.
    - ignore_stack -- If true, any stack-specific defaults are ignored.
    - restart -- If true, the web app will be restarted following the deployment. Set this to false if you are deploying multiple artifacts and do not want to restart the site on the earlier deployments.
    - slot -- The name of the slot. Default to the productions slot if not specified.
    - src_path -- Path of the artifact to be deployed. Ex: "myapp.zip" or "/myworkspace/apps/myapp.war"
    - src_url -- URL of the artifact. The webapp will pull the artifact from this URL. Ex: "http://mysite.com/files/myapp.war?key=123"
    - target_path -- Absolute path that the artifact should be deployed to. Defaults to "home/site/wwwroot/" Ex: "/home/site/deployments/tools/", "/home/site/scripts/startup-script.sh".
    - timeout -- Timeout for the deployment operation in milliseconds.
    - type -- Used to override the type of artifact being deployed.
    '''
    return _call_az("az webapp deploy", locals())


def update(name, resource_group, add=None, client_affinity_enabled=None, force_dns_registration=None, force_string=None, https_only=None, remove=None, set=None, skip_custom_domain_verification=None, skip_dns_registration=None, slot=None, ttl_in_seconds=None):
    '''
    Update an existing web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - client_affinity_enabled -- Enables sending session affinity cookies.
    - force_dns_registration -- If true, web app hostname is force registered with DNS
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - https_only -- Redirect all traffic made to an app using HTTP to HTTPS.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - skip_custom_domain_verification -- If true, custom (non *.azurewebsites.net) domains associated with web app are not verified
    - skip_dns_registration -- If true web app hostname is not registered with DNS on creation
    - slot -- the name of the slot. Default to the productions slot if not specified
    - ttl_in_seconds -- Time to live in seconds for web app's default domain name
    '''
    return _call_az("az webapp update", locals())




'''
Manage Batch tasks.
'''
from ... pyaz_utils import _call_az
from . import file, subtask


def create(job_id, account_endpoint=None, account_key=None, account_name=None, affinity_id=None, application_package_references=None, command_line=None, environment_settings=None, json_file=None, max_task_retry_count=None, max_wall_clock_time=None, resource_files=None, retention_time=None, task_id=None):
    '''
    Create Batch tasks.

    Required Parameters:
    - job_id -- The ID of the job containing the task.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- The Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- The Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - affinity_id -- Required. You can pass the affinityId of a Node to indicate that this Task needs to run on that Compute Node. Note that this is just a soft affinity. If the target Compute Node is busy or unavailable at the time the Task is scheduled, then the Task will be scheduled elsewhere.
    - application_package_references -- The space-separated list of IDs specifying the application packages to be installed. Space-separated application IDs with optional version in 'id[#version]' format.
    - command_line -- The command line of the task. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux.
    - environment_settings -- A list of environment variable settings for the task. Space-separated values in 'key=value' format.
    - json_file -- The file containing the task(s) to create in JSON(formatted to match REST API request body). When submitting multiple tasks, accepts either an array of tasks or a TaskAddCollectionParamater. If this parameter is specified, all other parameters are ignored.
    - max_task_retry_count -- The maximum number of times the Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries for the Task executable due to a nonzero exit code. The Batch service will try the Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries the Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry the Task after the first attempt. If the maximum retry count is -1, the Batch service retries the Task without limit.
    - max_wall_clock_time -- If this is not specified, there is no time limit on how long the Task may run.
    - resource_files -- A list of files that the Batch service will download to the compute node before running the command line. Space-separated resource references in filename=httpurl format, with httpurl being any HTTP url with public access or a SAS url with read access.
    - retention_time -- The default is 7 days, i.e. the Task directory will be retained for 7 days unless the Compute Node is removed or the Job is deleted.
    - task_id -- The ID of the task.
    '''
    return _call_az("az batch task create", locals())


def list(job_id, account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, select=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-tasks.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch task list", locals())


def delete(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job from which to delete the Task.
    - task_id -- The ID of the Task to delete.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch task delete", locals())


def show(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job that contains the Task.
    - task_id -- The ID of the Task to get information about.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch task show", locals())


def reset(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, json_file=None, max_task_retry_count=None, max_wall_clock_time=None, retention_time=None):
    '''
    Reset the properties of a Batch task.

    Required Parameters:
    - job_id -- The ID of the Job containing the Task.
    - task_id -- The ID of the Task to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - json_file -- A file containing the constraints specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Constraints Arguments' are ignored.
    - max_task_retry_count -- The maximum number of times the Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries for the Task executable due to a nonzero exit code. The Batch service will try the Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries the Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry the Task after the first attempt. If the maximum retry count is -1, the Batch service retries the Task without limit.
    - max_wall_clock_time -- If this is not specified, there is no time limit on how long the Task may run. Expected format is an ISO-8601 duration.
    - retention_time -- The default is 7 days, i.e. the Task directory will be retained for 7 days unless the Compute Node is removed or the Job is deleted. Expected format is an ISO-8601 duration.
    '''
    return _call_az("az batch task reset", locals())


def reactivate(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job containing the Task.
    - task_id -- The ID of the Task to reactivate.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch task reactivate", locals())


def stop(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job containing the Task.
    - task_id -- The ID of the Task to terminate.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch task stop", locals())




'''
Manage routes of an IoT hub.
'''
from .... pyaz_utils import _call_az

def create(endpoint_name, hub_name, route_name, source_type, condition=None, enabled=None, resource_group=None):
    '''
    Create a route in IoT Hub.

    Required Parameters:
    - endpoint_name -- Name of the routing endpoint.
    - hub_name -- IoT Hub name.
    - route_name -- Name of the Route.
    - source_type -- Source of the route.

    Optional Parameters:
    - condition -- Condition that is evaluated to apply the routing rule.
    - enabled -- A boolean indicating whether to enable route to the Iot hub.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub route create", locals())


def show(hub_name, route_name, resource_group=None):
    '''
    Get information about the route in IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - route_name -- Name of the Route.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub route show", locals())


def list(hub_name, resource_group=None, source_type=None):
    '''
    Get all the routes in IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_type -- Source of the route.
    '''
    return _call_az("az iot hub route list", locals())


def delete(hub_name, resource_group=None, route_name=None, source_type=None):
    '''
    Delete all or mentioned route for your IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_name -- Name of the Route.
    - source_type -- Source of the route.
    '''
    return _call_az("az iot hub route delete", locals())


def update(hub_name, route_name, condition=None, enabled=None, endpoint_name=None, resource_group=None, source_type=None):
    '''
    Update a route in IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.
    - route_name -- Name of the Route.

    Optional Parameters:
    - condition -- Condition that is evaluated to apply the routing rule.
    - enabled -- A boolean indicating whether to enable route to the Iot hub.
    - endpoint_name -- Name of the routing endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_type -- Source of the route.
    '''
    return _call_az("az iot hub route update", locals())


def test(hub_name, app_properties=None, body=None, resource_group=None, route_name=None, source_type=None, system_properties=None):
    '''
    Test all routes or mentioned route in IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - app_properties -- App properties of the route message.
    - body -- Body of the route message.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_name -- Name of the Route.
    - source_type -- Source of the route.
    - system_properties -- System properties of the route message.
    '''
    return _call_az("az iot hub route test", locals())




'''
Manage Azure API Management API's.
'''
from ... pyaz_utils import _call_az
from . import operation, release, revision, versionset


def import_(path, resource_group, service_name, specification_format, api_id=None, api_revision=None, api_type=None, api_version=None, api_version_set_id=None, description=None, display_name=None, no_wait=None, protocols=None, service_url=None, soap_api_type=None, specification_path=None, specification_url=None, subscription_key_header_name=None, subscription_key_query_param_name=None, subscription_required=None, wsdl_endpoint_name=None, wsdl_service_name=None):
    '''
    Import an API Management API.

    Required Parameters:
    - path -- Required. Relative URL uniquely identifying this API and all of its resource paths within the API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    - specification_format -- Specify the format of the imported API.

    Optional Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - api_revision -- Describes the Revision of the Api. If no value is provided, default revision 1 is created.
    - api_type -- The type of the API.
    - api_version -- Describes the Version of the Api. If you add a version to a non-versioned API, an Original version will be automatically created and will respond on the default URL
    - api_version_set_id -- Describes the Version Set to be used with the API
    - description -- Description of the API. May include HTML formatting tags.
    - display_name -- Display name of this API.
    - no_wait -- Do not wait for the long-running operation to finish.
    - protocols -- Describes on which protocols(one or more) the operations in this API can be invoked.
    - service_url -- Absolute URL of the backend service implementing this API. Cannot be more than 2000 characters long.
    - soap_api_type -- The type of API when file format is WSDL.
    - specification_path -- File path specified to import the API.
    - specification_url -- Url specified to import the API.
    - subscription_key_header_name -- Specifies the subscription key header name.
    - subscription_key_query_param_name -- Specifies the subscription key query string parameter name.
    - subscription_required -- If true, the API requires a subscription key on requests.
    - wsdl_endpoint_name -- Local name of WSDL Endpoint (port) to be imported.
    - wsdl_service_name -- Local name of WSDL Service to be imported.
    '''
    return _call_az("az apim api import", locals())


def create(api_id, display_name, path, resource_group, service_name, api_type=None, authorization_scope=None, authorization_server_id=None, bearer_token_sending_methods=None, description=None, no_wait=None, open_id_provider_id=None, protocols=None, service_url=None, subscription_key_header_name=None, subscription_key_query_param_name=None, subscription_key_required=None, subscription_required=None):
    '''
    Create an API Management API.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - display_name -- API name. Must be 1 to 300 characters long.
    - path -- Required. Relative URL uniquely identifying this API and all of its resource paths within the API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - api_type -- The type of the API.
    - authorization_scope -- Specifies the OAuth operations scope.
    - authorization_server_id -- Specifies the OAuth authorization server ID.
    - bearer_token_sending_methods -- Specifies the sending methods for bearer token.
    - description -- Description of the API. May include HTML formatting tags.
    - no_wait -- Do not wait for the long-running operation to finish.
    - open_id_provider_id -- Specifies the openid in the authentication setting.
    - protocols -- Describes on which protocols the operations in this API can be invoked.
    - service_url -- Absolute URL of the backend service implementing this API. Cannot be more than 2000 characters long.
    - subscription_key_header_name -- Specifies the subscription key header name.
    - subscription_key_query_param_name -- Specifies the subscription key query string parameter name.
    - subscription_key_required -- Specifies whether subscription key is required during call to this API, true - API is included into closed products only, false - API is included into open products alone, null - there is a mix of products.
    - subscription_required -- If true, the API requires a subscription key on requests.
    '''
    return _call_az("az apim api create", locals())


def show(api_id, resource_group, service_name):
    '''
    Show details of an API Management API.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim api show", locals())


def list(resource_group, service_name, filter_display_name=None, skip=None, top=None):
    '''
    List API Management API's.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - filter_display_name -- Filter of APIs by displayName.
    - skip -- Number of records to skip.
    - top -- Number of records to return.
    '''
    return _call_az("az apim api list", locals())


def delete(api_id, resource_group, service_name, delete_revisions=None, if_match=None, no_wait=None, yes=None):
    '''
    Delete an API Management API.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - delete_revisions -- Delete all revisions of the Api.
    - if_match -- ETag of the Entity.
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az apim api delete", locals())


def update(api_id, resource_group, service_name, add=None, api_type=None, description=None, display_name=None, force_string=None, if_match=None, no_wait=None, path=None, protocols=None, remove=None, service_url=None, set=None, subscription_key_header_name=None, subscription_key_query_param_name=None, subscription_required=None, tags=None):
    '''
    Update an API Management API.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - api_type -- The type of the API.
    - description -- Description of the API. May include HTML formatting tags.
    - display_name -- API name. Must be 1 to 300 characters long.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- ETag of the Entity. Not required when creating an entity, but required when updating an entity.
    - no_wait -- Do not wait for the long-running operation to finish.
    - path -- Required. Relative URL uniquely identifying this API and all of its resource paths within the API Management service instance.
    - protocols -- Describes on which protocols the operations in this API can be invoked.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service_url -- Absolute URL of the backend service implementing this API. Cannot be more than 2000 characters long.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - subscription_key_header_name -- Specifies the subscription key header name.
    - subscription_key_query_param_name -- Specifies the subscription key query string parameter name.
    - subscription_required -- If true, the API requires a subscription key on requests.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az apim api update", locals())


def wait(api_id, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of an apim api is met.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - name -- The name of the api management service instance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az apim api wait", locals())




'''
Manage app service plans.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, app_service_environment=None, hyper_v=None, is_linux=None, location=None, no_wait=None, number_of_workers=None, per_site_scaling=None, sku=None, tags=None, zone_redundant=None):
    '''
    Create an app service plan.

    Required Parameters:
    - name -- Name of the new app service plan
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - app_service_environment -- Name or ID of the app service environment
    - hyper_v -- Host web app on Windows container
    - is_linux -- host web app on Linux worker
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - number_of_workers -- Number of workers to be allocated.
    - per_site_scaling -- Enable per-app scaling at the App Service plan level to allow for scaling an app independently from the App Service plan that hosts it.
    - sku -- The pricing tiers, e.g., F1(Free), D1(Shared), B1(Basic Small), B2(Basic Medium), B3(Basic Large), S1(Standard Small), P1V2(Premium V2 Small), P1V3(Premium V3 Small), P2V3(Premium V3 Medium), P3V3(Premium V3 Large), PC2 (Premium Container Small), PC3 (Premium Container Medium), PC4 (Premium Container Large), I1 (Isolated Small), I2 (Isolated Medium), I3 (Isolated Large), I1v2 (Isolated V2 Small), I2v2 (Isolated V2 Medium), I3v2 (Isolated V2 Large)
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_redundant -- Enable zone redundancy for high availability. Cannot be changed after plan creation. Minimum instance count is 3.
    '''
    return _call_az("az appservice plan create", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete an app service plan.

    Required Parameters:
    - name -- The name of the app service plan
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appservice plan delete", locals())


def list(resource_group=None):
    '''
    List app service plans.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice plan list", locals())


def show(name, resource_group):
    '''
    Get the app service plans for a resource group or a set of resource groups.

    Required Parameters:
    - name -- The name of the app service plan
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice plan show", locals())


def update(name, resource_group, add=None, force_string=None, no_wait=None, number_of_workers=None, remove=None, set=None, sku=None):
    '''
    Update an app service plan.

    Required Parameters:
    - name -- The name of the app service plan
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - number_of_workers -- Number of workers to be allocated.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- The pricing tiers, e.g., F1(Free), D1(Shared), B1(Basic Small), B2(Basic Medium), B3(Basic Large), S1(Standard Small), P1V2(Premium V2 Small), P1V3(Premium V3 Small), P2V3(Premium V3 Medium), P3V3(Premium V3 Large), PC2 (Premium Container Small), PC3 (Premium Container Medium), PC4 (Premium Container Large), I1 (Isolated Small), I2 (Isolated Medium), I3 (Isolated Large), I1v2 (Isolated V2 Small), I2v2 (Isolated V2 Medium), I3v2 (Isolated V2 Large)
    '''
    return _call_az("az appservice plan update", locals())




from ... pyaz_utils import _call_az

def list(subscription_id):
    '''
    Get list of applicable reservation order ids.

    Required Parameters:
    - subscription_id -- Id of the subscription
    '''
    return _call_az("az reservations reservation-order-id list", locals())




from ..... pyaz_utils import _call_az

def add(connection_monitor, location, name, protocol, test_groups, frequency=None, http_method=None, http_path=None, http_port=None, http_prefer_https=None, http_request_header=None, http_valid_status_codes=None, icmp_disable_trace_route=None, preferred_ip_version=None, tcp_disable_trace_route=None, tcp_port=None, tcp_port_behavior=None, threshold_failed_percent=None, threshold_round_trip_time=None):
    '''
    Add a test configuration to a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor test configuration
    - protocol -- The protocol to use in test evaluation
    - test_groups -- Space-separated list of names of test group which only need to be affected if specified

    Optional Parameters:
    - frequency -- The frequency of test evaluation, in seconds
    - http_method -- The HTTP method to use
    - http_path -- The path component of the URI. For instance, "/dir1/dir2"
    - http_port -- The port to connect to
    - http_prefer_https -- Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit
    - http_request_header -- The HTTP headers to transmit with the request. List of property=value pairs to define HTTP headers.
    - http_valid_status_codes -- Space-separated list of HTTP status codes to consider successful. For instance, "2xx 301-304 418"
    - icmp_disable_trace_route -- Value indicating whether path evaluation with trace route should be disabled. false is default.
    - preferred_ip_version -- The preferred IP version to use in test evaluation. The connection monitor may choose to use a different version depending on other parameters
    - tcp_disable_trace_route -- Value indicating whether path evaluation with trace route should be disabled. false is default.
    - tcp_port -- The port to connect to
    - tcp_port_behavior -- Destination port behavior
    - threshold_failed_percent -- The maximum percentage of failed checks permitted for a test to evaluate as successful
    - threshold_round_trip_time -- The maximum round-trip time in milliseconds permitted for a test to evaluate as successful
    '''
    return _call_az("az network watcher connection-monitor test-configuration add", locals())


def remove(connection_monitor, location, name, test_groups=None):
    '''
    Remove a test configuration from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor test configuration

    Optional Parameters:
    - test_groups -- Space-separated list of names of test group which only need to be affected if specified
    '''
    return _call_az("az network watcher connection-monitor test-configuration remove", locals())


def show(connection_monitor, location, name):
    '''
    Show a test configuration from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor test configuration
    '''
    return _call_az("az network watcher connection-monitor test-configuration show", locals())


def list(connection_monitor, location):
    '''
    List all test configurations of a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network watcher connection-monitor test-configuration list", locals())




from ... pyaz_utils import _call_az

def create(name, replication_role, resource_group, server_to_link):
    '''
    Adds a server link to the Redis cache (requires Premium SKU).

    Required Parameters:
    - name -- Name of the Redis cache.
    - replication_role -- Role of the redis cache to be linked
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_to_link -- Resource ID or name of the redis cache to be linked
    '''
    return _call_az("az redis server-link create", locals())


def delete(linked_server_name, name, resource_group):
    '''
    

    Required Parameters:
    - linked_server_name -- Name of the linked redis cache
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis server-link delete", locals())


def show(linked_server_name, name, resource_group):
    '''
    

    Required Parameters:
    - linked_server_name -- Name of the linked redis cache
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis server-link show", locals())


def list(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis server-link list", locals())




'''
Manage login credentials for Azure Container Registries.
'''
from ... pyaz_utils import _call_az

def show(name, resource_group=None):
    '''
    Get the login credentials for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr credential show", locals())


def renew(name, password_name, resource_group=None):
    '''
    Regenerate login credentials for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - password_name -- The name of password to regenerate

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr credential renew", locals())




from ..... pyaz_utils import _call_az

def create(name, resource_group, workspace_name, no_wait=None, resource_id=None, write_access_resource_id=None):
    '''
    Create a linked service.

    Required Parameters:
    - name -- Name of the linkedServices resource. Supported values: cluster, automation.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_id -- The resource id of the resource that will be linked to the workspace. This should be used for linking resources which require read access.
    - write_access_resource_id -- The resource id of the resource that will be linked to the workspace. This should be used for linking resources which require write access.
    '''
    return _call_az("az monitor log-analytics workspace linked-service create", locals())


def update(name, resource_group, workspace_name, add=None, force_string=None, no_wait=None, remove=None, resource_id=None, set=None, write_access_resource_id=None):
    '''
    Update a linked service.

    Required Parameters:
    - name -- Name of the linkedServices resource. Supported values: cluster, automation.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_id -- The resource id of the resource that will be linked to the workspace. This should be used for linking resources which require read access.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - write_access_resource_id -- The resource id of the resource that will be linked to the workspace. This should be used for linking resources which require write access.
    '''
    return _call_az("az monitor log-analytics workspace linked-service update", locals())


def show(name, resource_group, workspace_name):
    '''
    Show the properties of a linked service.

    Required Parameters:
    - name -- Name of the linkedServices resource. Supported values: cluster, automation.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-service show", locals())


def list(resource_group, workspace_name):
    '''
    Gets all the linked services in a workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace linked-service list", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a linked service.

    Required Parameters:
    - name -- Name of the linkedServices resource. Supported values: cluster, automation.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az monitor log-analytics workspace linked-service delete", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the linked service is met.

    Required Parameters:
    - name -- Name of the linkedServices resource. Supported values: cluster, automation.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az monitor log-analytics workspace linked-service wait", locals())




'''
Managed identities for App Configurations.
'''
from ... pyaz_utils import _call_az

def assign(name, identities=None, resource_group=None):
    '''
    Update managed identities for an App Configuration.

    Required Parameters:
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`

    Optional Parameters:
    - identities -- Accept system-assigned or user-assigned managed identities separated by spaces. Use '[system]' to refer to system-assigned managed identity or a resource ID to refer to user-assigned managed identity. If this argument is not provided or this argument is provided without any value, system-assigned managed identity will be used by default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appconfig identity assign", locals())


def remove(name, identities=None, resource_group=None):
    '''
    Remove managed identities for an App Configuration.

    Required Parameters:
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`

    Optional Parameters:
    - identities -- Accept system-assigned or user-assigned managed identities separated by spaces. Use '[system]' to refer to system-assigned managed identity, '[all]' for all managed identities or a resource ID to refer user-assigned managed identity. If this argument is not provided or this argument is provided without any value, system-assigned managed identity will be removed by default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appconfig identity remove", locals())


def show(name, resource_group=None):
    '''
    Display managed identities for an App Configuration.

    Required Parameters:
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appconfig identity show", locals())




'''
Manage Cross-Origin Resource Sharing (CORS)
'''
from ... pyaz_utils import _call_az

def add(allowed_origins, name, resource_group, slot=None):
    '''
    Add allowed origins

    Required Parameters:
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*" and remove all other origins from the list
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp cors add", locals())


def remove(allowed_origins, name, resource_group, slot=None):
    '''
    Remove allowed origins

    Required Parameters:
    - allowed_origins -- space separated origins that should be allowed to make cross-origin calls (for example: http://example.com:12345). To allow all, use "*" and remove all other origins from the list
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp cors remove", locals())


def show(name, resource_group, slot=None):
    '''
    show allowed origins

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp cors show", locals())




'''
Manage Azure Container Instances.
'''
from .. pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List container groups.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az container list", locals())


def create(resource_group, acr_identity=None, assign_identity=None, azure_file_volume_account_key=None, azure_file_volume_account_name=None, azure_file_volume_mount_path=None, azure_file_volume_share_name=None, command_line=None, cpu=None, dns_name_label=None, environment_variables=None, file=None, gitrepo_dir=None, gitrepo_mount_path=None, gitrepo_revision=None, gitrepo_url=None, image=None, ip_address=None, location=None, log_analytics_workspace=None, log_analytics_workspace_key=None, memory=None, name=None, no_wait=None, os_type=None, ports=None, protocol=None, registry_login_server=None, registry_password=None, registry_username=None, restart_policy=None, role=None, scope=None, secrets=None, secrets_mount_path=None, secure_environment_variables=None, subnet=None, subnet_address_prefix=None, vnet=None, vnet_address_prefix=None, vnet_name=None, zone=None):
    '''
    Create a container group.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - acr_identity -- The identity with access to the container registry
    - assign_identity -- Space-separated list of assigned identities. Assigned identities are either user assigned identities (resource IDs) and / or the system assigned identity ('[system]'). See examples for more info.
    - azure_file_volume_account_key -- The storage account access key used to access the Azure File share
    - azure_file_volume_account_name -- The name of the storage account that contains the Azure File share
    - azure_file_volume_mount_path -- The path within the container where the azure file volume should be mounted. Must not contain colon ':'.
    - azure_file_volume_share_name -- The name of the Azure File share to be mounted as a volume
    - command_line -- The command line to run when the container is started, e.g. '/bin/bash -c myscript.sh'
    - cpu -- The required number of CPU cores of the containers, accurate to one decimal place
    - dns_name_label -- The dns name label for container group with public IP
    - environment_variables -- A list of environment variable for the container. Space-separated values in 'key=value' format.
    - file -- The path to the input file.
    - gitrepo_dir -- The target directory path in the git repository. Must not contain '..'.
    - gitrepo_mount_path -- The path within the container where the git repo volume should be mounted. Must not contain colon ':'.
    - gitrepo_revision -- The commit hash for the specified revision
    - gitrepo_url -- The URL of a git repository to be mounted as a volume
    - image -- The container image name
    - ip_address -- The IP address type of the container group
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - log_analytics_workspace -- The Log Analytics workspace name or id. Use the current subscription or use --subscription flag to set the desired subscription.
    - log_analytics_workspace_key -- The Log Analytics workspace key.
    - memory -- The required memory of the containers in GB, accurate to one decimal place
    - name -- The name of the container group
    - no_wait -- Do not wait for the long-running operation to finish.
    - os_type -- The OS type of the containers
    - ports -- A list of ports to open. Space-separated list of ports
    - protocol -- The network protocol to use
    - registry_login_server -- The container image registry login server
    - registry_password -- The password to log in container image registry server
    - registry_username -- The username to log in container image registry server
    - restart_policy -- Restart policy for all containers within the container group
    - role -- Role name or id the system assigned identity will have
    - scope -- Scope that the system assigned identity can access
    - secrets -- space-separated secrets in 'key=value' format.
    - secrets_mount_path -- The path within the container where the secrets volume should be mounted. Must not contain colon ':'.
    - secure_environment_variables -- A list of secure environment variable for the container. Space-separated values in 'key=value' format.
    - subnet -- The name of the subnet when creating a new VNET or referencing an existing one. Can also reference an existing subnet by ID.
    - subnet_address_prefix -- The subnet IP address prefix to use when creating a new VNET in CIDR format.
    - vnet -- The name of the VNET when creating a new one or referencing an existing one. Can also reference an existing vnet by ID. This allows using vnets from other resource groups.
    - vnet_address_prefix -- The IP address prefix to use when creating a new VNET in CIDR format.
    - vnet_name -- The name of the VNET when creating a new one or referencing an existing one.
    - zone -- The zone to place the container group.
    '''
    return _call_az("az container create", locals())


def show(name, resource_group):
    '''
    Get the details of a container group.

    Required Parameters:
    - name -- The name of the container group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az container show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a container group.

    Required Parameters:
    - name -- The name of the container group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az container delete", locals())


def logs(name, resource_group, container_name=None, follow=None):
    '''
    Examine the logs for a container in a container group.

    Required Parameters:
    - name -- The name of the container group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - container_name -- The container name to tail the logs. If omitted, the first container in the container group will be chosen
    - follow -- Indicate to stream the tailing logs
    '''
    return _call_az("az container logs", locals())


def exec(exec_command, name, resource_group, container_name=None):
    '''
    Execute a command from within a running container of a container group.

    Required Parameters:
    - exec_command -- The command to run from within the container
    - name -- The name of the container group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - container_name -- The container name where to execute the command. Can be ommitted for container groups with only one container.
    '''
    return _call_az("az container exec", locals())


def export(file, name, resource_group):
    '''
    Export a container group in yaml format.

    Required Parameters:
    - file -- The file path to export the container group.
    - name -- The name of the container group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az container export", locals())


def attach(name, resource_group, container_name=None):
    '''
    Attach local standard output and error streams to a container in a container group.

    Required Parameters:
    - name -- The name of the container group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - container_name -- The container to attach to. If omitted, the first container in the container group will be chosen
    '''
    return _call_az("az container attach", locals())


def restart(name, resource_group, no_wait=None):
    '''
    

    Required Parameters:
    - name -- The name of the container group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az container restart", locals())


def stop(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the container group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az container stop", locals())


def start(name, resource_group, no_wait=None):
    '''
    

    Required Parameters:
    - name -- The name of the container group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az container start", locals())




'''
Commands to work with files generated by node setup task.
'''
from .... pyaz_utils import _call_az

def list(cluster, resource_group, workspace, expiry=None, path=None):
    '''
    List files generated by the cluster's node setup task.

    Required Parameters:
    - cluster -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - expiry -- Time in minutes for how long generated download URLs should remain valid.
    - path -- Relative path of a subfolder inside of the node setup task output directory.
    '''
    return _call_az("az batchai cluster file list", locals())




from .. pyaz_utils import _call_az

def on():
    '''
    Turn on local context
    '''
    return _call_az("az local-context on", locals())


def off():
    '''
    Turn off local context
    '''
    return _call_az("az local-context off", locals())


def show(name=None):
    '''
    Show local context data

    Optional Parameters:
    - name -- Space-separated list of local context parameter names.
    '''
    return _call_az("az local-context show", locals())


def delete(all=None, name=None, purge=None, recursive=None, yes=None):
    '''
    Delete local context data

    Optional Parameters:
    - all -- Clear all local context data. Either --name or --all can be specified.
    - name -- Space-separated list of local context parameter names. Either --name or --all can be specified.
    - purge -- Delete local context file from working directory. Only available when --all is specified.
    - recursive -- Indicate this is recursive delete of local context. Only available when --all is specified.
    - yes -- Do not prompt for confirmation. Only available when --all is specified.
    '''
    return _call_az("az local-context delete", locals())




from .... pyaz_utils import _call_az

def create(endpoints, key, name, value, resource_group=None):
    '''
    Create a message enrichment for chosen endpoints in your IoT Hub

    Required Parameters:
    - endpoints -- Endpoint(s) to apply enrichments to. Use a space-separated list for multiple endpoints.
    - key -- The enrichment's key.
    - name -- IoT Hub name.
    - value -- The enrichment's value.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub message-enrichment create", locals())


def list(name, resource_group=None):
    '''
    Get information on all message enrichments for your IoT Hub

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub message-enrichment list", locals())


def delete(key, name, resource_group=None):
    '''
    Delete a message enrichment in your IoT hub (by key)

    Required Parameters:
    - key -- The enrichment's key.
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub message-enrichment delete", locals())


def update(endpoints, key, name, value, resource_group=None):
    '''
    Update a message enrichment in your IoT hub (by key)

    Required Parameters:
    - endpoints -- Endpoint(s) to apply enrichments to. Use a space-separated list for multiple endpoints.
    - key -- The enrichment's key.
    - name -- IoT Hub name.
    - value -- The enrichment's value.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub message-enrichment update", locals())




from .... pyaz_utils import _call_az

def create(application, cluster_name, correlated_service_name, name, resource_group, scheme):
    '''
    Create a new managed service correlation scheme on an Azure Service Fabric managed cluster.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - correlated_service_name -- Specify the Arm Resource ID of the service that the correlation relationship is established with.
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - scheme -- Specify the ServiceCorrelationScheme which describes the relationship between this service and the service specified via correlated_service_name.
    '''
    return _call_az("az sf managed-service correlation-scheme create", locals())


def update(application, cluster_name, correlated_service_name, name, resource_group, scheme):
    '''
    Update a managed service correlation scheme.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - correlated_service_name -- Specify the Arm Resource ID of the service that the correlation relationship is established with.
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - scheme -- Specify the ServiceCorrelationScheme which describes the relationship between this service and the service specified via correlated_service_name.
    '''
    return _call_az("az sf managed-service correlation-scheme update", locals())


def delete(application, cluster_name, correlated_service_name, name, resource_group):
    '''
    Delete a managed service correlation scheme.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - correlated_service_name -- Specify the Arm Resource ID of the service that the correlation relationship is established with.
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-service correlation-scheme delete", locals())




from ..... pyaz_utils import _call_az

def assign(identity, name, resource_group, no_wait=None):
    '''
    Assign a managed service identity to an ExpressRoute Port

    Required Parameters:
    - identity -- Name or ID of the ManagedIdentity Resource
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network express-route port identity assign", locals())


def remove(name, resource_group, no_wait=None):
    '''
    Remove the managed service identity of an ExpressRoute Port

    Required Parameters:
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network express-route port identity remove", locals())


def show(name, resource_group):
    '''
    Show the managed service identity of an ExpressRoute Port

    Required Parameters:
    - name -- ExpressRoute port name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route port identity show", locals())




'''
Manage encryption of VM disks.
'''
from ... pyaz_utils import _call_az

def enable(disk_encryption_keyvault, name, resource_group, aad_client_cert_thumbprint=None, aad_client_id=None, aad_client_secret=None, encrypt_format_all=None, force=None, key_encryption_algorithm=None, key_encryption_key=None, key_encryption_keyvault=None, volume_type=None):
    '''
    Enable disk encryption on the OS disk and/or data disks. Encrypt mounted disks.

    Required Parameters:
    - disk_encryption_keyvault -- Name or ID of the key vault where the generated encryption key will be placed.
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - aad_client_cert_thumbprint -- None
    - aad_client_id -- None
    - aad_client_secret -- None
    - encrypt_format_all -- Encrypts-formats data disks instead of encrypting them. Encrypt-formatting is a lot faster than in-place encryption but wipes out the partition getting encrypt-formatted.
    - force -- continue by ignoring client side validation errors
    - key_encryption_algorithm -- None
    - key_encryption_key -- Key vault key name or URL used to encrypt the disk encryption key.
    - key_encryption_keyvault -- Name or ID of the key vault containing the key encryption key used to encrypt the disk encryption key. If missing, CLI will use `--disk-encryption-keyvault`.
    - volume_type -- Type of volume that the encryption operation is performed on
    '''
    return _call_az("az vm encryption enable", locals())


def disable(name, resource_group, force=None, volume_type=None):
    '''
    Disable disk encryption on the OS disk and/or data disks. Decrypt mounted disks.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- continue by ignoring client side validation errors
    - volume_type -- Type of volume that the encryption operation is performed on
    '''
    return _call_az("az vm encryption disable", locals())


def show(name, resource_group):
    '''
    Show encryption status.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm encryption show", locals())




'''
Manage the Azure Monitor Service.
'''
from .. pyaz_utils import _call_az
from . import action_group, activity_log, alert, autoscale, autoscale_settings, diagnostic_settings, log_profiles, metrics, private_link_scope


def clone(source_resource, target_resource, always_clone=None, types=None):
    '''
    Clone metrics alert rules from one resource to another resource.

    Required Parameters:
    - source_resource -- Resource ID of the source resource.
    - target_resource -- Resource ID of the target resource.

    Optional Parameters:
    - always_clone -- If this argument is applied, all monitor settings would be cloned instead of expanding its scope.
    - types -- List of types of monitor settings which would be cloned.
    '''
    return _call_az("az monitor clone", locals())




'''
Manage a database's transparent data encryption.
'''
from .... pyaz_utils import _call_az

def set(database, resource_group, server, status):
    '''
    Sets a database's transparent data encryption configuration.

    Required Parameters:
    - database -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - status -- Status of the transparent data encryption.
    '''
    return _call_az("az sql db tde set", locals())


def show(database, resource_group, server):
    '''
    

    Required Parameters:
    - database -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db tde show", locals())


def list_activity(database, resource_group, server):
    '''
    

    Required Parameters:
    - database -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db tde list-activity", locals())




'''
Manage network interfaces. See also `az network nic`.
'''
from ... pyaz_utils import _call_az

def add(nics, resource_group, vm_name, primary_nic=None):
    '''
    Add existing NICs to a VM.

    Required Parameters:
    - nics -- Names or IDs of NICs.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - primary_nic -- Name or ID of the primary NIC. If missing, the first NIC in the list will be the primary.
    '''
    return _call_az("az vm nic add", locals())


def remove(nics, resource_group, vm_name, primary_nic=None):
    '''
    Remove NICs from a VM.

    Required Parameters:
    - nics -- Names or IDs of NICs.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - primary_nic -- Name or ID of the primary NIC. If missing, the first NIC in the list will be the primary.
    '''
    return _call_az("az vm nic remove", locals())


def set(nics, resource_group, vm_name, primary_nic=None):
    '''
    Configure settings of a NIC attached to a VM.

    Required Parameters:
    - nics -- Names or IDs of NICs.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - primary_nic -- Name or ID of the primary NIC. If missing, the first NIC in the list will be the primary.
    '''
    return _call_az("az vm nic set", locals())


def show(nic, resource_group, vm_name):
    '''
    Display information for a NIC attached to a VM.

    Required Parameters:
    - nic -- NIC name or ID.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm nic show", locals())


def list(resource_group, vm_name):
    '''
    List the NICs available on a VM.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm nic list", locals())




from .... pyaz_utils import _call_az

def show(name):
    '''
    Show the detail of an Azure network virtual appliance sku.

    Required Parameters:
    - name -- The name of Network Virtual Appliance SKU
    '''
    return _call_az("az network virtual-appliance sku show", locals())


def list():
    '''
    List all Azure network virtual appliance sku.
    '''
    return _call_az("az network virtual-appliance sku list", locals())




from .... pyaz_utils import _call_az

def add(capacity, cluster_name, node_type, resource_group, vm_password, vm_user_name, durability_level=None, vm_sku=None, vm_tier=None):
    '''
    Add a new node type to a cluster.

    Required Parameters:
    - capacity -- The capacity tag applied to nodes in the node type. The cluster resource manager uses these tags to understand how much capacity a node has.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - node_type -- the Node type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - vm_password -- The password of the Vm
    - vm_user_name -- The user name for logging to Vm. Default will be adminuser

    Optional Parameters:
    - durability_level -- durability level.
    - vm_sku -- VM Sku
    - vm_tier -- VM tier.
    '''
    return _call_az("az sf cluster node-type add", locals())




'''
Manage Azure Event Grid topics.
'''
from ... pyaz_utils import _call_az
from . import key


def show(name, resource_group):
    '''
    Get the details of a topic.

    Required Parameters:
    - name -- Name of the topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid topic show", locals())


def delete(name, resource_group):
    '''
    Delete a topic.

    Required Parameters:
    - name -- Name of the topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid topic delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available topics.

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid topic list", locals())


def create(name, resource_group, extended_location_name=None, extended_location_type=None, identity=None, inbound_ip_rules=None, input_mapping_default_values=None, input_mapping_fields=None, input_schema=None, kind=None, location=None, public_network_access=None, sku=None, tags=None):
    '''
    Create a topic.

    Required Parameters:
    - name -- Name of the topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - extended_location_name -- The extended location name if kind==azurearc.
    - extended_location_type -- The extended location type if kind==azurearc.
    - identity -- The managed identity type for the resource.
    - inbound_ip_rules -- None
    - input_mapping_default_values -- When input-schema is specified as customeventschema, this parameter can be used to specify input mappings based on default values. You can use this parameter when your custom schema does not include a field that corresponds to one of the three fields supported by this parameter. Specify space separated mappings in 'key=value' format. Allowed key names are 'subject', 'eventtype', 'dataversion'. The corresponding value names should specify the default values to be used for the mapping and they will be used only when the published event doesn't have a valid mapping for a particular field.
    - input_mapping_fields -- When input-schema is specified as customeventschema, this parameter is used to specify input mappings based on field names. Specify space separated mappings in 'key=value' format. Allowed key names are 'id', 'topic', 'eventtime', 'subject', 'eventtype', 'dataversion'. The corresponding value names should specify the names of the fields in the custom input schema. If a mapping for either 'id' or 'eventtime' is not provided, Event Grid will auto-generate a default value for these two fields.
    - input_schema -- Schema in which incoming events will be published to this topic/domain. If you specify customeventschema as the value for this parameter, you must also provide values for at least one of --input_mapping_default_values / --input_mapping_fields.
    - kind -- The kind of topic resource.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - public_network_access -- This determines if traffic is allowed over public network. By default it is enabled. You can further restrict to specific IPs by configuring.
    - sku -- The Sku name of the resource.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventgrid topic create", locals())


def update(name, resource_group, identity=None, inbound_ip_rules=None, public_network_access=None, sku=None, tags=None):
    '''
    Update a topic.

    Required Parameters:
    - name -- Name of the topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identity -- The managed identity type for the resource.
    - inbound_ip_rules -- None
    - public_network_access -- This determines if traffic is allowed over public network. By default it is enabled. You can further restrict to specific IPs by configuring.
    - sku -- The Sku name of the resource.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventgrid topic update", locals())




from .... pyaz_utils import _call_az

def show(account_name, resource_group):
    '''
    Get the data policy rules associated with the specified storage account.

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account management-policy show", locals())


def create(account_name, policy, resource_group):
    '''
    Create the data policy rules associated with the specified storage account.

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group.
    - policy -- The Storage Account ManagementPolicies Rules, in JSON format. See more details in: https://docs.microsoft.com/azure/storage/common/storage-lifecycle-managment-concepts.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account management-policy create", locals())


def update(account_name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update the data policy rules associated with the specified storage account.

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az storage account management-policy update", locals())


def delete(account_name, resource_group):
    '''
    Delete the data policy rules associated with the specified storage account.

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account management-policy delete", locals())




'''
Manage operations on a database.
'''
from .... pyaz_utils import _call_az

def list(database, resource_group, server):
    '''
    

    Required Parameters:
    - database -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db op list", locals())


def cancel(database, name, resource_group, server):
    '''
    

    Required Parameters:
    - database -- Name of the Azure SQL Database.
    - name -- The unique name of the operation to cancel.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db op cancel", locals())




from .... pyaz_utils import _call_az

def list(account_endpoint=None, account_key=None, account_name=None, end_time=None, filter=None, start_time=None):
    '''
    

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - end_time -- The latest time from which to include metrics. This must be at least two hours before the current time. If not specified this defaults to the end time of the last aggregation interval currently available.
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-account-usage-metrics.
    - start_time -- The earliest time from which to include metrics. This must be at least two and a half hours before the current time. If not specified this defaults to the start time of the last aggregation interval currently available.
    '''
    return _call_az("az batch pool usage-metrics list", locals())




'''
Commands to manage workspaces.
'''
from ... pyaz_utils import _call_az

def create(resource_group, workspace, location=None):
    '''
    Create a workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - location -- Location of the workspace. If omitted, the location of the resource group will be used.
    '''
    return _call_az("az batchai workspace create", locals())


def show(resource_group, workspace):
    '''
    Show information about a workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai workspace show", locals())


def list(resource_group=None):
    '''
    List workspaces.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az batchai workspace list", locals())


def delete(resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete a workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batchai workspace delete", locals())




from .... pyaz_utils import _call_az

def delete(account_name=None, id=None, name=None, resource_group=None, yes=None):
    '''
    Delete a private endpoint connection request for storage account.

    Optional Parameters:
    - account_name -- The storage account name.
    - id -- The ID of the private endpoint connection associated with the Storage Account. You can get it using `az storage account show`.
    - name -- The name of the private endpoint connection associated with the Storage Account.
    - resource_group -- The resource group name of specified storage account.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage account private-endpoint-connection delete", locals())


def show(account_name=None, id=None, name=None, resource_group=None):
    '''
    Show details of a private endpoint connection request for storage account.

    Optional Parameters:
    - account_name -- The storage account name.
    - id -- The ID of the private endpoint connection associated with the Storage Account. You can get it using `az storage account show`.
    - name -- The name of the private endpoint connection associated with the Storage Account.
    - resource_group -- The resource group name of specified storage account.
    '''
    return _call_az("az storage account private-endpoint-connection show", locals())


def approve(account_name=None, description=None, id=None, name=None, resource_group=None):
    '''
    Approve a private endpoint connection request for storage account.

    Optional Parameters:
    - account_name -- The storage account name.
    - description -- Comments for approve operation.
    - id -- The ID of the private endpoint connection associated with the Storage Account. You can get it using `az storage account show`.
    - name -- The name of the private endpoint connection associated with the Storage Account.
    - resource_group -- The resource group name of specified storage account.
    '''
    return _call_az("az storage account private-endpoint-connection approve", locals())


def reject(account_name=None, description=None, id=None, name=None, resource_group=None):
    '''
    Reject a private endpoint connection request for storage account.

    Optional Parameters:
    - account_name -- The storage account name.
    - description -- Comments for reject operation.
    - id -- The ID of the private endpoint connection associated with the Storage Account. You can get it using `az storage account show`.
    - name -- The name of the private endpoint connection associated with the Storage Account.
    - resource_group -- The resource group name of specified storage account.
    '''
    return _call_az("az storage account private-endpoint-connection reject", locals())




'''
Manage Data Lake Analytics job recurrences.
'''
from .... pyaz_utils import _call_az

def show(account, recurrence_identity, end_date_time=None, start_date_time=None):
    '''
    Retrieve a job recurrence in a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - recurrence_identity -- Recurrence ID.

    Optional Parameters:
    - end_date_time -- The end date for when to get recurrence and aggregate its data. The startDateTime and endDateTime can be no more than 30 days apart.
    - start_date_time -- The start date for when to get the recurrence and aggregate its data. The startDateTime and endDateTime can be no more than 30 days apart.
    '''
    return _call_az("az dla job recurrence show", locals())


def list(account, end_date_time=None, start_date_time=None):
    '''
    List job recurrences in a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - end_date_time -- The end date for when to get the list of recurrences. The startDateTime and endDateTime can be no more than 30 days apart.
    - start_date_time -- The start date for when to get the list of recurrences. The startDateTime and endDateTime can be no more than 30 days apart.
    '''
    return _call_az("az dla job recurrence list", locals())




from .... pyaz_utils import _call_az

def create(endpoint_name, endpoint_resource_group, endpoint_subscription_id, endpoint_type, hub_name, auth_type=None, batch_frequency=None, chunk_size=None, connection_string=None, container_name=None, encoding=None, endpoint_uri=None, entity_path=None, file_name_format=None, identity=None, resource_group=None):
    '''
    Add an endpoint to your IoT Hub.

    Required Parameters:
    - endpoint_name -- Name of the Routing Endpoint.
    - endpoint_resource_group -- Resource group of the Endpoint resoure.
    - endpoint_subscription_id -- SubscriptionId of the Endpoint resource.
    - endpoint_type -- Type of the Routing Endpoint.
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - auth_type -- Authentication type for the endpoint. The default is keyBased.
    - batch_frequency -- Request batch frequency in seconds. The maximum amount of time that can elapse before data is written to a blob, between 60 and 720 seconds.
    - chunk_size -- Request chunk size in megabytes(MB). The maximum size of blobs, between 10 and 500 MB.
    - connection_string -- Connection string of the Routing Endpoint.
    - container_name -- Name of the storage container.
    - encoding -- Encoding format for the container. The default is AVRO. Note that this field is applicable only for blob container endpoints.
    - endpoint_uri -- The uri of the endpoint resource.
    - entity_path -- The entity path of the endpoint resource.
    - file_name_format -- File name format for the blob. The file name format must contain {iothub}, {partition}, {YYYY}, {MM}, {DD}, {HH} and {mm} fields. All parameters are mandatory but can be reordered with or without delimiters.
    - identity -- Use a system-assigned or user-assigned managed identity for endpoint authentication. Use "[system]" to refer to the system-assigned identity or a resource ID to refer to a user-assigned identity. If you use --auth-type without this parameter, system-assigned managed identity is assumed.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub routing-endpoint create", locals())


def show(endpoint_name, hub_name, resource_group=None):
    '''
    Get information on mentioned endpoint for your IoT Hub.

    Required Parameters:
    - endpoint_name -- Name of the Routing Endpoint.
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub routing-endpoint show", locals())


def list(hub_name, endpoint_type=None, resource_group=None):
    '''
    Get information on all the endpoints for your IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - endpoint_type -- Type of the Routing Endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub routing-endpoint list", locals())


def delete(hub_name, endpoint_name=None, endpoint_type=None, resource_group=None):
    '''
    Delete all or mentioned endpoint for your IoT Hub.

    Required Parameters:
    - hub_name -- IoT Hub name.

    Optional Parameters:
    - endpoint_name -- Name of the Routing Endpoint.
    - endpoint_type -- Type of the Routing Endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub routing-endpoint delete", locals())




from ..... pyaz_utils import _call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of an A record set.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - record_type -- ==SUPPRESS==
    '''
    return _call_az("az network private-dns record-set a show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete an A record set and all associated records.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - if_match -- The ETag of the record set. Omit this value to always delete the current record set. Specify the last-seen ETag value to prevent accidentally deleting any concurrent changes.
    - record_type -- ==SUPPRESS==
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network private-dns record-set a delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List all A record sets in a zone.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - record_type -- ==SUPPRESS==
    '''
    return _call_az("az network private-dns record-set a list", locals())


def create(name, resource_group, zone_name, metadata=None, record_type=None, ttl=None):
    '''
    Create an empty A record set.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - record_type -- ==SUPPRESS==
    - ttl -- Record set TTL (time-to-live)
    '''
    return _call_az("az network private-dns record-set a create", locals())


def add_record(ipv4_address, record_set_name, resource_group, zone_name):
    '''
    Add an A record.

    Required Parameters:
    - ipv4_address -- IPV4 address in string notation.
    - record_set_name -- The name of the record set relative to the zone. Creates a new record set if one does not exist.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.
    '''
    return _call_az("az network private-dns record-set a add-record", locals())


def remove_record(ipv4_address, record_set_name, resource_group, zone_name, keep_empty_record_set=None):
    '''
    Remove an A record from its record set.

    Required Parameters:
    - ipv4_address -- IPV4 address in string notation.
    - record_set_name -- The name of the record set relative to the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - keep_empty_record_set -- Keep the empty record set if the last record is removed.
    '''
    return _call_az("az network private-dns record-set a remove-record", locals())


def update(name, resource_group, zone_name, add=None, force_string=None, if_match=None, metadata=None, record_type=None, remove=None, set=None):
    '''
    Update an A record set.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the Private DNS zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the Private DNS zone.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- The ETag of the record set. Omit this value to always overwrite the current record set. Specify the last-seen ETag value to prevent accidentally overwriting concurrent changes.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - record_type -- ==SUPPRESS==
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network private-dns record-set a update", locals())




'''
Manage data warehouses.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, server, backup_storage_redundancy=None, collation=None, max_size=None, no_wait=None, service_objective=None, tags=None, zone_redundant=None):
    '''
    Create a data warehouse.

    Required Parameters:
    - name -- Name of the data warehouse.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - collation -- The collation of the data warehouse.
    - max_size -- The max storage size. If no unit is specified, defaults to bytes (B).
    - no_wait -- Do not wait for the long-running operation to finish.
    - service_objective -- The service objective for the new database. For example: DW100, DW1000c
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql dw create", locals())


def show(name, resource_group, server):
    '''
    Get the details for a data warehouse.

    Required Parameters:
    - name -- Name of the data warehouse.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql dw show", locals())


def list(resource_group, server):
    '''
    List data warehouses for a server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql dw list", locals())


def delete(name, resource_group, server, no_wait=None, yes=None):
    '''
    Delete a data warehouse.

    Required Parameters:
    - name -- Name of the data warehouse.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql dw delete", locals())


def pause(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- Name of the data warehouse.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql dw pause", locals())


def resume(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- Name of the data warehouse.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql dw resume", locals())


def update(name, resource_group, server, add=None, force_string=None, max_size=None, no_wait=None, remove=None, service_objective=None, set=None):
    '''
    Update a data warehouse.

    Required Parameters:
    - name -- Name of the data warehouse.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - max_size -- The max storage size. If no unit is specified, defaults to bytes (B).
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service_objective -- The service objective of the data warehouse. For example: DW100, DW1000c
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az sql dw update", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, workspace_name, compute_type=None, core_count=None, description=None, if_match=None, location=None, no_wait=None, time_to_live=None):
    '''
    Create an managed integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - compute_type -- Compute type of the data flow cluster which will execute data flow job.
    - core_count -- Core count of the data flow cluster which will execute data flow job.
    - description -- The integration runtime description.
    - if_match -- ETag of the integration runtime entity. Should only be specified for update, for which it should match existing entity or can be * for unconditional update.
    - location -- The integration runtime location.
    - no_wait -- Do not wait for the long-running operation to finish.
    - time_to_live -- Time to live (in minutes) setting of the data flow cluster which will execute data flow job.
    '''
    return _call_az("az synapse integration-runtime managed create", locals())




'''
Manage Azure Active Directory groups.
'''
from ... pyaz_utils import _call_az
from . import member, owner


def delete(group):
    '''
    

    Required Parameters:
    - group -- group's object id or display name(prefix also works if there is a unique match)
    '''
    return _call_az("az ad group delete", locals())


def show(group):
    '''
    

    Required Parameters:
    - group -- group's object id or display name(prefix also works if there is a unique match)
    '''
    return _call_az("az ad group show", locals())


def get_member_groups(group, additional_properties=None, security_enabled_only=None):
    '''
    

    Required Parameters:
    - group -- group's object id or display name(prefix also works if there is a unique match)

    Optional Parameters:
    - additional_properties -- Unmatched properties from the message are deserialized this collection
    - security_enabled_only -- If true, only membership in security-enabled groups should be checked. Otherwise, membership in all groups should be checked.
    '''
    return _call_az("az ad group get-member-groups", locals())


def list(display_name=None, filter=None):
    '''
    

    Optional Parameters:
    - display_name -- object's display name or its prefix
    - filter -- OData filter, e.g. --filter "displayname eq 'test' and servicePrincipalType eq 'Application'"
    '''
    return _call_az("az ad group list", locals())


def create(display_name, mail_nickname, description=None, force=None):
    '''
    Create a group in the directory.

    Required Parameters:
    - display_name -- object's display name or its prefix
    - mail_nickname -- Mail nickname

    Optional Parameters:
    - description -- Group description
    - force -- always create a new group instead of updating the one with same display and mail nickname
    '''
    return _call_az("az ad group create", locals())




from ..... pyaz_utils import _call_az
from . import match_condition


def create(action, name, policy_name, priority, resource_group, rule_type):
    '''
    Create an application gateway WAF policy custom rule.

    Required Parameters:
    - action -- Action to take.
    - name -- Name of the WAF policy rule.
    - policy_name -- The name of the application gateway WAF policy.
    - priority -- Rule priority. Lower values are evaluated prior to higher values.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_type -- Type of rule.
    '''
    return _call_az("az network application-gateway waf-policy custom-rule create", locals())


def delete(name, policy_name, resource_group):
    '''
    Delete an application gateway WAF policy custom rule.

    Required Parameters:
    - name -- Name of the WAF policy rule.
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy custom-rule delete", locals())


def list(policy_name, resource_group):
    '''
    List application gateway WAF policy custom rules.

    Required Parameters:
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy custom-rule list", locals())


def show(name, policy_name, resource_group):
    '''
    Get the details of an application gateway WAF policy custom rule.

    Required Parameters:
    - name -- Name of the WAF policy rule.
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy custom-rule show", locals())


def update(name, policy_name, resource_group, action=None, add=None, force_string=None, priority=None, remove=None, rule_type=None, set=None):
    '''
    Update an application gateway WAF policy custom rule.

    Required Parameters:
    - name -- Name of the WAF policy rule.
    - policy_name -- The name of the application gateway WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - action -- Action to take.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - priority -- Rule priority. Lower values are evaluated prior to higher values.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - rule_type -- Type of rule.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network application-gateway waf-policy custom-rule update", locals())




'''
Manage Azure Cognitive Services accounts.
'''
from .... pyaz_utils import _call_az

def regenerate(key_name, name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.

    Required Parameters:
    - key_name -- Key name to generate
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account keys regenerate", locals())


def list(name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account keys list", locals())




'''
Manage app settings the static app.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group=None):
    '''
    List app settings of the static app.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp appsettings list", locals())


def set(name, setting_names, resource_group=None):
    '''
    Add to or change the app settings of the static app.

    Required Parameters:
    - name -- Name of the static site
    - setting_names -- Space-separated app settings in 'key=value' format. 

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp appsettings set", locals())


def delete(name, setting_names, resource_group=None):
    '''
    Delete app settings with given keys of the static app.

    Required Parameters:
    - name -- Name of the static site
    - setting_names -- Space-separated app setting names.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp appsettings delete", locals())




from .... pyaz_utils import _call_az

def add(data, gateway_name, name, resource_group):
    '''
    Add trusted client certificate of the application gateway.

    Required Parameters:
    - data -- Certificate public data.
    - gateway_name -- Name of the application gateway.
    - name -- Name of the trusted client certificate that is unique within an Application Gateway
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway client-cert add", locals())


def remove(gateway_name, name, resource_group):
    '''
    Remove an existing trusted client certificate of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the trusted client certificate that is unique within an Application Gateway
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway client-cert remove", locals())


def list(gateway_name, resource_group):
    '''
    List the existing trusted client certificate of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway client-cert list", locals())


def show(gateway_name, name, resource_group):
    '''
    Show an existing trusted client certificate of the application gateway.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- Name of the trusted client certificate that is unique within an Application Gateway
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway client-cert show", locals())


def update(data, gateway_name, name, resource_group):
    '''
    Update trusted client certificate of the application gateway.

    Required Parameters:
    - data -- Certificate public data.
    - gateway_name -- Name of the application gateway.
    - name -- Name of the trusted client certificate that is unique within an Application Gateway
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway client-cert update", locals())




'''
Manage function keys.
'''
from .... pyaz_utils import _call_az

def set(function_name, key_name, name, resource_group, key_value=None, slot=None):
    '''
    Create or update a function key.

    Required Parameters:
    - function_name -- Name of the Function
    - key_name -- Name of the key to set.
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - key_value -- Value of the new key. If not provided, a value will be generated.
    - slot -- The name of the slot. Defaults to the productions slot if not specified
    '''
    return _call_az("az functionapp function keys set", locals())


def list(function_name, name, resource_group, slot=None):
    '''
    List all function keys.

    Required Parameters:
    - function_name -- Name of the Function
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot. Defaults to the productions slot if not specified
    '''
    return _call_az("az functionapp function keys list", locals())


def delete(key_name, name, resource_group, function_name=None, slot=None):
    '''
    Delete a function key.

    Required Parameters:
    - key_name -- Name of the key to set.
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - function_name -- Name of the Function
    - slot -- The name of the slot. Defaults to the productions slot if not specified
    '''
    return _call_az("az functionapp function keys delete", locals())




'''
Manage metrics for a vm.
'''
from .... pyaz_utils import _call_az

def tail(name, resource_group, aggregation=None, dimension=None, end_time=None, filter=None, interval=None, metadata=None, metrics=None, namespace=None, offset=None, orderby=None, start_time=None, top=None):
    '''
    List the metric values for a VM.

    Required Parameters:
    - name -- Name or ID of a virtual machine
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - aggregation -- None
    - dimension -- None
    - end_time -- End time of the query. Defaults to the current time. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - filter -- None
    - interval -- None
    - metadata -- None
    - metrics -- None
    - namespace -- None
    - offset -- None
    - orderby -- Aggregation to use for sorting results and the direction of the sort. Only one order can be specificed. Examples: sum asc
    - start_time -- Start time of the query. Format: date (yyyy-mm-dd) time (hh:mm:ss.xxxxx) timezone (+/-hh:mm)
    - top -- Max number of records to retrieve. Valid only if --filter used.
    '''
    return _call_az("az vm monitor metrics tail", locals())


def list_definitions(name, resource_group, namespace=None):
    '''
    List the metric definitions for a VM.

    Required Parameters:
    - name -- Name or ID of a virtual machine
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - namespace -- Namespace to query metric definitions for.
    '''
    return _call_az("az vm monitor metrics list-definitions", locals())




from ..... pyaz_utils import _call_az

def set(action, duration, name, policy_name, priority, request_threshold, resource_group, disabled=None):
    '''
    Add a rate limit rule to a CDN WAF policy.

    Required Parameters:
    - action -- None
    - duration -- None
    - name -- The name of the rate limit rule.
    - policy_name -- Name of the CDN WAF policy.
    - priority -- None
    - request_threshold -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disabled -- None
    '''
    return _call_az("az cdn waf policy rate-limit-rule set", locals())


def delete(name, policy_name, resource_group, yes=None):
    '''
    Remove a rate limit rule from a CDN WAF policy.

    Required Parameters:
    - name -- The name of the rate limit rule.
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cdn waf policy rate-limit-rule delete", locals())


def list(policy_name, resource_group):
    '''
    List rate limit rules of a CDN WAF policy.

    Required Parameters:
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn waf policy rate-limit-rule list", locals())


def show(name, policy_name, resource_group):
    '''
    Show a rate limit rule of a CDN WAF policy.

    Required Parameters:
    - name -- The name of the rate limit rule.
    - policy_name -- Name of the CDN WAF policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn waf policy rate-limit-rule show", locals())




from .... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List all read replicas for a given server.

    Required Parameters:
    - name -- Name of the source server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql flexible-server replica list", locals())


def create(replica_name, resource_group, source_server, no_wait=None, zone=None):
    '''
    Create a read replica for a server.

    Required Parameters:
    - replica_name -- The name of the server to restore to.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_server -- The name or resource ID of the source server to restore from.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az mysql flexible-server replica create", locals())


def stop_replication(name, resource_group, yes=None):
    '''
    Stop replication to a read replica and make it a read/write server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql flexible-server replica stop-replication", locals())




from .... pyaz_utils import _call_az

def list(gateway_name, resource_group):
    '''
    List HTTP settings.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway http-settings list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a gateway's HTTP settings.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the backed HTTP settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway http-settings show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete HTTP settings.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the backed HTTP settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway http-settings delete", locals())


def create(gateway_name, name, port, resource_group, affinity_cookie_name=None, auth_certs=None, connection_draining_timeout=None, cookie_based_affinity=None, enable_probe=None, host_name=None, host_name_from_backend_pool=None, no_wait=None, path=None, probe=None, protocol=None, root_certs=None, timeout=None):
    '''
    Create HTTP settings.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the backed HTTP settings.
    - port -- The port number.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - affinity_cookie_name -- Name used for the affinity cookie.
    - auth_certs -- Space-separated list of authentication certificates (names or IDs) to associate with the HTTP settings.
    - connection_draining_timeout -- The time in seconds after a backend server is removed during which on open connection remains active. Range: 0 (disabled) to 3600
    - cookie_based_affinity -- Enable or disable cookie-based affinity.
    - enable_probe -- Whether the probe is enabled.
    - host_name -- Host header sent to the backend servers.
    - host_name_from_backend_pool -- Use host name of the backend server as the host header.
    - no_wait -- Do not wait for the long-running operation to finish.
    - path -- Path that will prefix all HTTP requests.
    - probe -- Name or ID of the probe to associate with the HTTP settings.
    - protocol -- The HTTP settings protocol.
    - root_certs -- Space-separated list of trusted root certificates (names or IDs) to associate with the HTTP settings. --host-name or --host-name-from-backend-pool is required when this field is set.
    - timeout -- Request timeout in seconds.
    '''
    return _call_az("az network application-gateway http-settings create", locals())


def update(gateway_name, name, resource_group, add=None, affinity_cookie_name=None, auth_certs=None, connection_draining_timeout=None, cookie_based_affinity=None, enable_probe=None, force_string=None, host_name=None, host_name_from_backend_pool=None, no_wait=None, path=None, port=None, probe=None, protocol=None, remove=None, root_certs=None, set=None, timeout=None):
    '''
    Update HTTP settings.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the backed HTTP settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - affinity_cookie_name -- Name used for the affinity cookie.
    - auth_certs -- Space-separated list of authentication certificates (names or IDs) to associate with the HTTP settings.
    - connection_draining_timeout -- The time in seconds after a backend server is removed during which on open connection remains active. Range: 0 (disabled) to 3600
    - cookie_based_affinity -- Enable or disable cookie-based affinity.
    - enable_probe -- Whether the probe is enabled.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - host_name -- Host header sent to the backend servers.
    - host_name_from_backend_pool -- Use host name of the backend server as the host header.
    - no_wait -- Do not wait for the long-running operation to finish.
    - path -- Path that will prefix all HTTP requests.
    - port -- The port number.
    - probe -- Name or ID of the probe to associate with the HTTP settings.
    - protocol -- The HTTP settings protocol.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - root_certs -- Space-separated list of trusted root certificates (names or IDs) to associate with the HTTP settings. --host-name or --host-name-from-backend-pool is required when this field is set.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - timeout -- Request timeout in seconds.
    '''
    return _call_az("az network application-gateway http-settings update", locals())




from ... pyaz_utils import _call_az

def invoke(command_id, instance_id, name, resource_group, parameters=None, scripts=None):
    '''
    Execute a specific run command on a Virtual Machine Scale Set instance.

    Required Parameters:
    - command_id -- The command id. Use 'az vmss run-command list' to get the list
    - instance_id -- None
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - parameters -- space-separated parameters in the format of '[name=]value'
    - scripts -- Space-separated script lines. Use @{file} to load script from a file
    '''
    return _call_az("az vmss run-command invoke", locals())


def list(instance_id, resource_group, vmss_name, expand=None):
    '''
    The operation to get all run commands of an instance in Virtual Machine Scaleset.

    Required Parameters:
    - instance_id -- The instance ID of the virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- The name of the VM scale set.

    Optional Parameters:
    - expand -- The expand expression to apply on the operation.
    '''
    return _call_az("az vmss run-command list", locals())


def show(instance_id, name, resource_group, vmss_name, expand=None, instance_view=None):
    '''
    The operation to get the VMSS run command.

    Required Parameters:
    - instance_id -- The instance ID of the virtual machine.
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- The name of the VM scale set.

    Optional Parameters:
    - expand -- The expand expression to apply on the operation.
    - instance_view -- Track the run command progress
    '''
    return _call_az("az vmss run-command show", locals())


def create(instance_id, name, resource_group, vmss_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to Create the VMSS VM run command.

    Required Parameters:
    - instance_id -- The instance ID of the virtual machine.
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- The name of the VM scale set.

    Optional Parameters:
    - async_execution -- Optional. If set to true, provisioning will complete as soon as the script starts and will not wait for script to complete.
    - command_id -- Specify a command id of predefined script. All command ids can be listed using "list" command.
    - error_blob_uri -- Uri (without SAS) to an append blob where the script error stream will be uploaded.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - output_blob_uri -- Uri (without SAS) to an append blob where the script output will be uploaded.
    - parameters -- Set custom parameters in a name-value pair.
    - protected_parameters -- Set custom parameters in a name-value pair. These parameters will be encrypted during transmission and will not be logged.
    - run_as_password -- Password if needed for using run-as-user parameter. It will be encrypted and not logged. 
    - run_as_user -- By default script process runs under system/root user. Specify custom user to host the process.
    - script -- Contain the powershell or bash script to execute on the VM.
    - script_uri -- Contain a uri to the script to execute on the VM. Uri can be any link accessible from the VM or a storage blob without SAS. If subscription has access to the storage blob, then SAS will be auto-generated. 
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - timeout_in_seconds -- The timeout in seconds to execute the run command.
    '''
    return _call_az("az vmss run-command create", locals())


def update(instance_id, name, resource_group, vmss_name, async_execution=None, command_id=None, error_blob_uri=None, location=None, no_wait=None, output_blob_uri=None, parameters=None, protected_parameters=None, run_as_password=None, run_as_user=None, script=None, script_uri=None, tags=None, timeout_in_seconds=None):
    '''
    The operation to update the VMSS run command.

    Required Parameters:
    - instance_id -- The instance ID of the virtual machine.
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- The name of the VM scale set.

    Optional Parameters:
    - async_execution -- Optional. If set to true, provisioning will complete as soon as the script starts and will not wait for script to complete.
    - command_id -- Specify a command id of predefined script. All command ids can be listed using "list" command.
    - error_blob_uri -- Uri (without SAS) to an append blob where the script error stream will be uploaded.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - output_blob_uri -- Uri (without SAS) to an append blob where the script output will be uploaded.
    - parameters -- Set custom parameters in a name-value pair.
    - protected_parameters -- Set custom parameters in a name-value pair. These parameters will be encrypted during transmission and will not be logged.
    - run_as_password -- Password if needed for using run-as-user parameter. It will be encrypted and not logged. 
    - run_as_user -- By default script process runs under system/root user. Specify custom user to host the process.
    - script -- Contain the powershell or bash script to execute on the VM.
    - script_uri -- Contain a uri to the script to execute on the VM. Uri can be any link accessible from the VM or a storage blob without SAS. If subscription has access to the storage blob, then SAS will be auto-generated. 
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - timeout_in_seconds -- The timeout in seconds to execute the run command.
    '''
    return _call_az("az vmss run-command update", locals())


def delete(instance_id, name, resource_group, vmss_name, no_wait=None, yes=None):
    '''
    The operation to delete the run command.

    Required Parameters:
    - instance_id -- The instance ID of the virtual machine.
    - name -- The name of the virtual machine run command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- The name of the VM scale set.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az vmss run-command delete", locals())




'''
An item which is already protected or backed up to an Azure Recovery services vault with an associated policy.
'''
from ... pyaz_utils import _call_az

def show(container_name, name, resource_group, vault_name, backup_management_type=None, use_secondary_region=None, workload_type=None):
    '''
    Show details of a particular backed up item.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - name -- Name of the backed up item. You can use the backup item list command to get the name of a backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - use_secondary_region -- Use this flag to show item in secondary region.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup item show", locals())


def list(resource_group, vault_name, backup_management_type=None, container_name=None, use_secondary_region=None, workload_type=None):
    '''
    List all backed up items within a container.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - use_secondary_region -- Use this flag to list items in secondary region.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup item list", locals())


def set_policy(container_name, name, policy_name, resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    Update the policy associated with this item. Use this to change policies of the backup item.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - name -- Name of the backed up item. You can use the backup item list command to get the name of a backed up item.
    - policy_name -- Name of the Backup policy. You can use the backup policy list command to get the name of a backup policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup item set-policy", locals())




'''
manage web app's managed identity
'''
from ... pyaz_utils import _call_az

def assign(name, resource_group, identities=None, role=None, scope=None, slot=None):
    '''
    assign managed identity to the web app

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to assign. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    - role -- Role name or id the managed identity will be assigned
    - scope -- The scope the managed identity has access to
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp identity assign", locals())


def show(name, resource_group, slot=None):
    '''
    display web app's managed identity

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp identity show", locals())


def remove(name, resource_group, identities=None, slot=None):
    '''
    Disable web app's managed identity

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to assign. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp identity remove", locals())




from .... pyaz_utils import _call_az

def create(resource_group, server_name, charset=None, collation=None, database_name=None):
    '''
    Create a MySQL database on a flexible server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - charset -- The charset of the database. The default value is UTF8
    - collation -- The collation of the database.
    - database_name -- The name of the database to be created when provisioning the database server
    '''
    return _call_az("az mysql flexible-server db create", locals())


def delete(database_name=None, resource_group=None, server_name=None, yes=None):
    '''
    Delete a database on a flexible server.

    Optional Parameters:
    - database_name -- The name of the database to be created when provisioning the database server
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql flexible-server db delete", locals())


def show(database_name, resource_group, server_name):
    '''
    Show the details of a database.

    Required Parameters:
    - database_name -- The name of the database to be created when provisioning the database server
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mysql flexible-server db show", locals())


def list(resource_group, server_name):
    '''
    List the databases for a flexible server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mysql flexible-server db list", locals())




'''
See detail usage in 'az aks command invoke', 'az aks command result'.
'''
from ... pyaz_utils import _call_az

def invoke(name, resource_group, command=None, file=None, no_wait=None):
    '''
    Run a shell command (with kubectl, helm) on your aks cluster, support attaching files as well.

    Required Parameters:
    - name -- Name of the managed cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - command -- the command to run
    - file -- attach any files the command may use, or use '.' to upload the current folder.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az aks command invoke", locals())


def result(name, resource_group, command_id=None):
    '''
    Fetch result from previously triggered 'aks command invoke'.

    Required Parameters:
    - name -- Name of the managed cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - command_id -- the command ID from "aks command invoke"
    '''
    return _call_az("az aks command result", locals())




from .... pyaz_utils import _call_az

def add(name, repo, resource_group, branch=None, force=None, login_with_github=None, runtime=None, slot=None, token=None):
    '''
    Add a GitHub Actions workflow file to the specified repository. The workflow will build and deploy your app to the specified webapp.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - repo -- The GitHub repository to which the workflow file will be added. In the format: <owner>/<repository-name>
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - branch -- The branch to which the workflow file will be added. Defaults to "master" if not specified.
    - force -- When true, the command will overwrite any workflow file with a conflicting name.
    - login_with_github -- Interactively log in with Github to retrieve the Personal Access Token
    - runtime -- Canonicalized web runtime in the format of Framework|Version, e.g. "PHP|5.6". Use "az webapp list-runtimes" for available list.
    - slot -- The name of the slot. Default to the production slot if not specified.
    - token -- A Personal Access Token with write access to the specified repository. For more information: https://help.github.com/en/github/authenticating-to-github/creating-a-personal-access-token-for-the-command-line
    '''
    return _call_az("az webapp deployment github-actions add", locals())


def remove(name, repo, resource_group, branch=None, login_with_github=None, slot=None, token=None):
    '''
    Remove and disconnect the GitHub Actions workflow file from the specified repository.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - repo -- The GitHub repository to which the workflow file will be added. In the format: <owner>/<repository-name>
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - branch -- The branch to which the workflow file will be added. Defaults to "master" if not specified.
    - login_with_github -- Interactively log in with Github to retrieve the Personal Access Token
    - slot -- The name of the slot. Default to the production slot if not specified.
    - token -- A Personal Access Token with write access to the specified repository. For more information: https://help.github.com/en/github/authenticating-to-github/creating-a-personal-access-token-for-the-command-line
    '''
    return _call_az("az webapp deployment github-actions remove", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, server, subnet, ignore_missing_endpoint=None, vnet_name=None):
    '''
    Create a virtual network rule to allows access to an Azure SQL server.

    Required Parameters:
    - name -- The name of the virtual network rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - subnet -- Name or ID of the subnet that allows access to an Azure Sql Server. If subnet name is provided, --vnet-name must be provided.

    Optional Parameters:
    - ignore_missing_endpoint -- Create firewall rule before the virtual network has vnet service endpoint enabled
    - vnet_name -- The virtual network name
    '''
    return _call_az("az sql server vnet-rule create", locals())


def show(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the virtual network rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server vnet-rule show", locals())


def list(resource_group, server):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server vnet-rule list", locals())


def delete(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the virtual network rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server vnet-rule delete", locals())


def update(name, resource_group, server, subnet, ignore_missing_endpoint=None):
    '''
    Update a virtual network rule.

    Required Parameters:
    - name -- The name of the virtual network rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - subnet -- Name or ID of the subnet that allows access to an Azure Sql Server. If subnet name is provided, --vnet-name must be provided.

    Optional Parameters:
    - ignore_missing_endpoint -- Create firewall rule before the virtual network has vnet service endpoint enabled
    '''
    return _call_az("az sql server vnet-rule update", locals())




from .... pyaz_utils import _call_az

def add(cluster_name, resource_group, common_name=None, is_admin=None, issuer_thumbprint=None, thumbprint=None):
    '''
    Add a new client certificate to the managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - common_name -- Client certificate common name.
    - is_admin -- Client authentication type.
    - issuer_thumbprint -- Space-separated list of issuer thumbprints.
    - thumbprint -- Client certificate thumbprint.
    '''
    return _call_az("az sf managed-cluster client-certificate add", locals())


def delete(cluster_name, resource_group, common_name=None, thumbprint=None):
    '''
    Delete a client certificate from the managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - common_name -- A single or Space-separated list of client certificate common name(s) to be remove.
    - thumbprint -- A single or Space-separated list of client certificate thumbprint(s) to be remove.
    '''
    return _call_az("az sf managed-cluster client-certificate delete", locals())




'''
Manage Dedicated Hosts for Virtual Machines
'''
from ... pyaz_utils import _call_az
from . import group


def show(host_group, name, resource_group):
    '''
    Get the details of a dedicated host.

    Required Parameters:
    - host_group -- Name of the Dedicated Host Group
    - name -- Name of the Dedicated Host
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm host show", locals())


def get_instance_view(host_group, name, resource_group):
    '''
    Get instance information about a dedicated host.

    Required Parameters:
    - host_group -- Name of the Dedicated Host Group
    - name -- Name of the Dedicated Host
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm host get-instance-view", locals())


def create(host_group, name, resource_group, sku, auto_replace=None, license_type=None, location=None, platform_fault_domain=None, tags=None):
    '''
    Create a dedicated host.

    Required Parameters:
    - host_group -- Name of the Dedicated Host Group
    - name -- Name of the Dedicated Host
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- SKU of the dedicated host. Available SKUs: https://azure.microsoft.com/pricing/details/virtual-machines/dedicated-host/

    Optional Parameters:
    - auto_replace -- Replace the host automatically if a failure occurs
    - license_type -- The software license type that will be applied to the VMs deployed on the dedicated host.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`. Otherwise, location will default to the resource group's location
    - platform_fault_domain -- Fault domain of the host within a group. Allowed values: 0, 1, 2
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az vm host create", locals())


def list(host_group, resource_group):
    '''
    List dedicated hosts.

    Required Parameters:
    - host_group -- Name of the Dedicated Host Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm host list", locals())


def update(host_group, name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a dedicated host.

    Required Parameters:
    - host_group -- Name of the Dedicated Host Group
    - name -- Name of the Dedicated Host
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az vm host update", locals())


def delete(host_group, name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - host_group -- Name of the Dedicated Host Group
    - name -- Name of the Dedicated Host
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az vm host delete", locals())

